@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 {
-  $Git::Hooks::CheckJira::VERSION = '0.050';
+  $Git::Hooks::CheckJira::VERSION = '0.051';
 }
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages.
 
@@ -223,7 +223,7 @@ sub check_patchset {
     _setup_config($git);
 
     my $sha1   = $opts->{'--commit'};
-    my $commit = ($git->get_commits("$sha1^", $sha1))[-1];
+    my $commit = $git->get_commit($sha1);
 
     return check_commit_msg($git, $commit, $opts->{'--branch'});
 }
@@ -310,7 +310,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 DESCRIPTION
 
